@@ -1,22 +1,32 @@
-(*
- * bibtex2html - A BibTeX to HTML translator
- * Copyright (C) 1997-2000 Jean-Christophe Fillitre and Claude March
- * 
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2, as published by the Free Software Foundation.
- * 
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * See the GNU General Public License version 2 for more details
- * (enclosed in the file GPL).
- *)
+(**************************************************************************)
+(*  bibtex2html - A BibTeX to HTML translator                             *)
+(*  Copyright (C) 1997-2010 Jean-Christophe Fillitre and Claude March   *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU General Public                   *)
+(*  License version 2, as published by the Free Software Foundation.      *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(*  See the GNU General Public License version 2 for more details         *)
+(*  (enclosed in the file GPL).                                           *)
+(**************************************************************************)
 
-(*i $Id: latexmacros.ml,v 1.68 2008-01-10 14:43:44 filliatr Exp $ i*)
+(* This code is an adaptation of a code written by Xavier Leroy in
+   1995-1997, in its own made latex2html translator. See
 
-(*s This code is Copyright (C) 1997  Xavier Leroy. *)
+@inproceedings{Leroy-latex2html,
+               author =        "Xavier Leroy",
+               title =         "Lessons learned from the translation of
+                         documentation from \LaTeX\ to {HTML}",
+               booktitle =     "ERCIM/W4G Int. Workshop on WWW
+                         Authoring and Integration Tools",
+               year =          1995,
+               month =         feb}
+
+*)
 
 open Printf
 open Options
